# Generated by Django 5.2 on 2025-01-13 11:15

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0009_alter_biosample_space_alter_clinicaltrial_space_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="biosample",
            old_name="aux",
            new_name="_aux",
        ),
        migrations.RenameField(
            model_name="clinicaltrial",
            old_name="aux",
            new_name="_aux",
        ),
        migrations.RenameField(
            model_name="medication",
            old_name="aux",
            new_name="_aux",
        ),
        migrations.RenameField(
            model_name="patient",
            old_name="aux",
            new_name="_aux",
        ),
        migrations.RenameField(
            model_name="treatment",
            old_name="aux",
            new_name="_aux",
        ),
    ]
