# Generated by Django 5.2 on 2025-01-11 15:14

import django.db.models.deletion
import lamindb.base.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0007_alter_artifactbiosample_artifact_and_more"),
        ("lamindb", "0071_lamindbv1_migrate_schema"),
        ("bionty", "0043_lamindbv2_part2"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="biosample",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="clinicaltrial",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="medication",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="patient",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="treatment",
            name="_previous_runs",
        ),
        migrations.AddField(
            model_name="biosample",
            name="_branch_code",
            field=models.SmallIntegerField(db_default=1, db_index=True, default=1),
        ),
        migrations.AddField(
            model_name="biosample",
            name="aux",
            field=models.JSONField(db_default=None, default=None, null=True),
        ),
        migrations.AddField(
            model_name="biosample",
            name="space",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                to="lamindb.space",
            ),
        ),
        migrations.AddField(
            model_name="clinicaltrial",
            name="_branch_code",
            field=models.SmallIntegerField(db_default=1, db_index=True, default=1),
        ),
        migrations.AddField(
            model_name="clinicaltrial",
            name="aux",
            field=models.JSONField(db_default=None, default=None, null=True),
        ),
        migrations.AddField(
            model_name="clinicaltrial",
            name="space",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                to="lamindb.space",
            ),
        ),
        migrations.AddField(
            model_name="medication",
            name="_branch_code",
            field=models.SmallIntegerField(db_default=1, db_index=True, default=1),
        ),
        migrations.AddField(
            model_name="medication",
            name="aux",
            field=models.JSONField(db_default=None, default=None, null=True),
        ),
        migrations.AddField(
            model_name="medication",
            name="space",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                to="lamindb.space",
            ),
        ),
        migrations.AddField(
            model_name="patient",
            name="_branch_code",
            field=models.SmallIntegerField(db_default=1, db_index=True, default=1),
        ),
        migrations.AddField(
            model_name="patient",
            name="aux",
            field=models.JSONField(db_default=None, default=None, null=True),
        ),
        migrations.AddField(
            model_name="patient",
            name="space",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                to="lamindb.space",
            ),
        ),
        migrations.AddField(
            model_name="treatment",
            name="_branch_code",
            field=models.SmallIntegerField(db_default=1, db_index=True, default=1),
        ),
        migrations.AddField(
            model_name="treatment",
            name="aux",
            field=models.JSONField(db_default=None, default=None, null=True),
        ),
        migrations.AddField(
            model_name="treatment",
            name="space",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=1,
                on_delete=django.db.models.deletion.PROTECT,
                to="lamindb.space",
            ),
        ),
    ]
