# Generated by Django 5.2 on 2025-01-15 14:41

import django.db.models.functions.datetime
import lamindb.base.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0011_alter_biosample__aux_alter_clinicaltrial__aux_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="artifactbiosample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="artifactclinicaltrial",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="artifactmedication",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="artifactpatient",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="clinicaltrial",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="clinicaltrial",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="patient",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="patient",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="treatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="treatment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(
                blank=True,
                db_default=django.db.models.functions.datetime.Now(),
                db_index=True,
                editable=False,
            ),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactclinicaltrial",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactmedication",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactpatient",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="clinicaltrial",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="patient",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="treatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                editable=False,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
    ]
